==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/is.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud Texti",
    "text document" : "textaskjal",
    "Readme" : "Readme upplýsingaskrá",
    "Text" : "Texti",
    "📝 Collaborative document editing" : "📝 Samstarfsforrit til vinnslu skjala",
    "Use current version" : "Nota fyrirliggjandi útgáfu",
    "Use the saved version" : "Nota vistuðu útgáfuna",
    "Retry" : "Reyna aftur",
    "Last saved {lastSaved}" : "Síðast vistað {lastSaved}",
    "Unpushed changes" : "Breytingar sem ekki er búið að senda inn",
    "Unsaved changes" : "Óvistaðar breytingar",
    "Edit guest name" : "Breyta nafni gests",
    "Save guest name" : "Vista nafn gests",
    "Insert image" : "Setja inn mynd",
    "Add link" : "Bæta við tengli",
    "Show image" : "Birta mynd",
    "Show file" : "Sýna skrá",
    "Show rich workspaces" : "Birta vinnusvæði með sniðmöguleikum",
    "Add notes, lists or links …" : "Bættu við minnispunktum, listum eða tenglum …",
    "New text document" : "Nýtt textaskjal",
    "Edit" : "Breyta",
    "Undo" : "Afturkalla",
    "Redo" : "Endurtaka",
    "Bold" : "Feitletrað",
    "Italic" : "Skáletrað",
    "Strikethrough" : "Gegnumstrikað",
    "Paragraph" : "Málsgrein",
    "Headings" : "Fyrirsagnir",
    "Heading 1" : "Fyrirsögn 1",
    "Heading 2" : "Fyrirsögn 2",
    "Heading 3" : "Fyrirsögn 3",
    "Heading 4" : "Fyrirsögn 4",
    "Heading 5" : "Fyrirsögn 5",
    "Heading 6" : "Fyrirsögn 6",
    "Unordered list" : "Óraðaður listi",
    "Ordered list" : "Raðaður listi",
    "ToDo list" : "Verkefnalisti",
    "Blockquote" : "Tilvitnun",
    "Code block" : "Kóðablokk",
    "Last save {lastSave}" : "Síðast vistað {lastSave}",
    "New text document.md" : "Nýtt textaskjal.md"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/is.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud Texti",
    "text document" : "textaskjal",
    "Readme" : "Readme upplýsingaskrá",
    "Text" : "Texti",
    "📝 Collaborative document editing" : "📝 Samstarfsforrit til vinnslu skjala",
    "Use current version" : "Nota fyrirliggjandi útgáfu",
    "Use the saved version" : "Nota vistuðu útgáfuna",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Skjalinu hefur verið breytt utan ritilsins. Ekki var hægt að framkvæma breytingarnar.",
    "File could not be loaded. Please check your internet connection." : "Ekki var hægt að hlaða inn skránni. Athugaðu nettenginguna þína.",
    "Retry" : "Reyna aftur",
    "Last saved {lastSaved}" : "Síðast vistað {lastSaved}",
    "Unpushed changes" : "Breytingar sem ekki er búið að senda inn",
    "Unsaved changes" : "Óvistaðar breytingar",
    "Enter your name so other users can see who is editing" : "Settu inn nafnið þitt svo aðrir notendur geti séð hver sé að breyta hverju",
    "Edit guest name" : "Breyta nafni gests",
    "Save guest name" : "Vista nafn gests",
    "Insert image" : "Setja inn mynd",
    "Insert an image" : "Setja inn mynd",
    "Link file" : "Tengja skrá",
    "Select file to link to" : "Veldu skrá til að tengja í",
    "_and %n other editor_::_and %n other editors_" : ["og %n annar ritill","og %n aðrir ritlar"],
    "Show rich workspaces" : "Birta vinnusvæði með sniðmöguleikum",
    "Add notes, lists or links …" : "Bættu við minnispunktum, listum eða tenglum …",
    "New text document" : "Nýtt textaskjal",
    "Edit" : "Breyta",
    "Undo" : "Afturkalla",
    "Redo" : "Endurtaka",
    "Bold" : "Feitletrað",
    "Italic" : "Skáletrað",
    "Strikethrough" : "Gegnumstrikað",
    "Headings" : "Fyrirsagnir",
    "Heading 1" : "Fyrirsögn 1",
    "Heading 2" : "Fyrirsögn 2",
    "Heading 3" : "Fyrirsögn 3",
    "Heading 4" : "Fyrirsögn 4",
    "Heading 5" : "Fyrirsögn 5",
    "Heading 6" : "Fyrirsögn 6",
    "Unordered list" : "Óraðaður listi",
    "Ordered list" : "Raðaður listi",
    "ToDo list" : "Verkefnalisti",
    "Blockquote" : "Tilvitnun",
    "Code block" : "Kóðablokk",
    "Last save {lastSave}" : "Síðast vistað {lastSave}",
    "Add link" : "Bæta við tengli",
    "Show image" : "Birta mynd",
    "Show file" : "Sýna skrá",
    "Paragraph" : "Málsgrein"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
